@@ -46,6 +46,8 @@ else:
 
 
 class OfficePreviewBuilderLibreoffice(DocumentPreviewBuilder):
+    weight = 40
+
     @classmethod
     def get_label(cls) -> str:
         return "Documents - based on LibreOffice"
@@ -59,7 +61,11 @@ class OfficePreviewBuilderLibreoffice(DocumentPreviewBuilder):
         return [
             MimetypeMapping(
                 "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet", ".xlsx"
-            )
+            ),
+            MimetypeMapping("application/vnd.oasis.opendocument.text", ".odt"),
+            MimetypeMapping(
+                "application/vnd.openxmlformats-officedocument.wordprocessingml.document", ".docx"
+            ),
         ]
 
     @classmethod
@@ -329,8 +335,9 @@ LO_MIMETYPES = {
     # relatively uncommon image mimetypes
     "image/x-freehand": "fh",
     "image/cgm": "cgm",
-    "image/tif": "tiff",
-    "image/tiff": "tiff",
+    # INFO - G.M - 2021-06-23 Prefer imagemagick for this format
+    # "image/tif": "tiff",
+    # "image/tiff": "tiff",
     "image/vnd.dxf": "dxf",
     "image/emf": "emf",
     "image/x-emf": "emf",
